@@ -1,12 +1,12 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
     generate portrait landscape
-    north east south west
+    north east south west handson
     layout checkerboard animate
     chess checkers conway sudoku
     calculator dk shroom
@@ -16,6 +16,7 @@ our @EXPORT_OK = qw(
 use Clone;
 use HTML::AutoTag;
 use Math::Matrix;
+
 use Spreadsheet::HTML::Presets;
 use Spreadsheet::HTML::File::Loader;
 
@@ -28,14 +29,15 @@ sub south   { generate( @_, theta => -180, tgroups => 0, pinhead => 1 ) }
 sub west    { generate( @_, theta => -270, tgroups => 0 ) }
 
 sub layout          { Spreadsheet::HTML::Presets::layout(           @_ ) }
-sub conway          { Spreadsheet::HTML::Presets::conway(           @_ ) }
-sub calculator      { Spreadsheet::HTML::Presets::calculator(       @_ ) }
+sub handson         { Spreadsheet::HTML::Presets::Handson::handson( @_ ) }
+sub conway          { Spreadsheet::HTML::Presets::Conway::conway(   @_ ) }
+sub calculator      { Spreadsheet::HTML::Presets::Calculator::calculator( @_ ) }
 sub chess           { Spreadsheet::HTML::Presets::chess(            @_ ) }
 sub checkers        { Spreadsheet::HTML::Presets::checkers(         @_ ) }
-sub sudoku          { Spreadsheet::HTML::Presets::sudoku(           @_ ) }
+sub sudoku          { Spreadsheet::HTML::Presets::Sudoku::sudoku(   @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard(     @_ ) }
 sub calendar        { Spreadsheet::HTML::Presets::calendar(         @_ ) }
-sub animate         { Spreadsheet::HTML::Presets::animate(          @_ ) }
+sub animate         { Spreadsheet::HTML::Presets::Animate::animate( @_ ) }
 sub maze            { Spreadsheet::HTML::Presets::maze(             @_ ) }
 sub banner          { Spreadsheet::HTML::Presets::banner(           @_ ) }
 sub dk              { Spreadsheet::HTML::Presets::dk(               @_ ) }
@@ -86,7 +88,7 @@ sub generate {
     }
 
     if ($args{animate}) {
-        my ($js, %new_args) = Spreadsheet::HTML::Presets::animate(
+        my ($js, %new_args) = Spreadsheet::HTML::Presets::Animate::animate(
             %args,
             data => [ map [ map $_->{cdata}, @$_ ], @{ $args{data} } ],
         );
@@ -126,6 +128,8 @@ sub _process {
         }
     }
 
+    my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
+
     for my $row (0 .. $args->{_max_rows} - 1) {
 
         unless ($args->{_layout}) {
@@ -133,25 +137,15 @@ sub _process {
             pop  @{ $data->[$row] } for $args->{_max_cols} .. $#{ $data->[$row] };                 # truncate
         }
 
+        my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
         for my $col (0 .. $#{ $data->[$row] }) {
-            my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
 
             my ( $cdata, $attr ) = ( $data->[$row][$col], undef );
             for ($tag, "-c$col", "-r$row", "-r${row}c${col}") {
                 next unless exists $args->{$_};
-                my $new_attr;
-                $args->{$_} = [ $args->{$_} ] unless ref( $args->{$_} ) eq 'ARRAY';
-                for (@{ $args->{$_} }) {
-                    if (ref($_) eq 'CODE') {
-                        $cdata = $_->($cdata);
-                    } elsif (ref($_) eq 'HASH') {
-                        $new_attr = $_;
-                    }
-                }
-                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
+                ( $cdata, $attr ) = _expand_code_or_hash( $cdata, $attr, $args->{$_} );
             }
 
-            my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
             do{ no warnings; $cdata =~ s/^\s*$/$empty/g };
 
             $data->[$row][$col] = { 
@@ -212,9 +206,7 @@ sub _make_table {
         push @cdata, map { tag => 'tr', attr => $args{tr}, cdata => $_ }, @{ $args{data} };
     }
 
-    my $encodes = exists $args{encodes} ? $args{encodes} : '';
-    my $auto = HTML::AutoTag->new( encodes => $encodes, indent => $args{indent}, level => $args{level} );
-    return $auto->tag( tag => 'table', attr => $args{table}, cdata => [ @cdata ] );
+    return $args{_auto}->tag( tag => 'table', attr => $args{table}, cdata => [ @cdata ] );
 }
 
 sub _caption {
@@ -288,6 +280,9 @@ sub _args {
     $args = scalar @args ? { @args } : {};
     $data = delete $args->{data} if exists $args->{data};
 
+    my $encodes = exists $args->{encodes} ? $args->{encodes} : '';
+    $args->{_auto} = HTML::AutoTag->new( encodes => $encodes, indent => $args->{indent}, level => $args->{level} );
+
     if ($self) {
         return ( $self, $self->{data}, $args ) if $self->{is_cached};
         $args = { %{ $self || {} }, %{ $args || {} } };
@@ -320,6 +315,21 @@ sub _args {
     return ( $self, Clone::clone($data), $args );
 }
 
+sub _expand_code_or_hash {
+    my ( $cdata, $attr, $thingy ) = @_;
+    my $new_attr;
+    $thingy = [ $thingy ] unless ref( $thingy ) eq 'ARRAY';
+    for (@{ $thingy }) {
+        if (ref($_) eq 'CODE') {
+            $cdata = $_->($cdata);
+        } elsif (ref($_) eq 'HASH') {
+            $new_attr = $_;
+        }
+    }
+    $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
+    return ( $cdata, $attr );
+}
+
 sub _range {grep!(($_-$_[0])%($_[2]||1)),$_[0]..$_[1]}
 
 
@@ -353,10 +363,11 @@ Procedural interface:
 
 =head1 DESCRIPTION
 
-Generate HTML tables with ease (HTML4, XHTML and HTML5). Provides a handful
-of distinctly named methods to control overall table orientation.
-These methods in turn accept a number of distinctly named attributes
-for directing what tags and attributes to use.
+Generate HTML tables with ease (HTML4, XHTML and HTML5). Can generate
+landscape and other rotated views, Handsontable tables, HTML calendars,
+checkboard patterns, games such as sudoku, banners and mazes, and can
+create animations of cell values and backgrounds via jQuery. Can rewrap
+existing tables from Excel, HTML, JSON, CSV and YAML files.
 
 THIS MODULE IS AN ALPHA RELEASE! Although we are very close to BETA.
 
@@ -729,22 +740,24 @@ with little to no additional coding.
 
 =item * C<layout( %params )>
 
+=item * C<handson( handsonjs, jquery, css, %params )>
+
+=item * C<banner( on, off, text, font, %params )>
+
+=item * C<calendar( month, year, %params )>
+
+=item * C<animate( fgdirection, bgdirection, jquery, %params )>
+
 =item * C<conway( on, off, fade, jquery, %params )>
 
 =item * C<calculator( jquery, %params )>
 
-=item * C<calendar( month, year, %params )>
-
 =item * C<checkerboard( colors, %params )>
 
-=item * C<animate( fgdirection, bgdirection, jquery, %params )>
-
-=item * C<banner( on, off, text, font, %params )>
+=item * C<sudoku( blanks, attempts, %params )>
 
 =item * C<maze( on, off, fill, %params )>
 
-=item * C<sudoku( blanks, attempts, %params )>
-
 =item * C<chess( %params )>
 
 =item * C<checkers( %params )>
